fogcount

package
v0.0.0-...-601e5b2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 11, 2025 License: MIT Imports: 2 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Analyze

func Analyze(rdr io.Reader) float64

Analyze processes an English text and produces its Gunning Fox index score. Refer to its logic in https://en.wikipedia.org/wiki/Gunning_fog_index - it does not analyse word endings (-es, -ed, or -ing), or discriminate proper nouns, familiar jargon or compound words.

Types

This section is empty.

Source Files

  • fg.go

Jump to